@@ -462,7 +462,7 @@
 #define	PVR_405CR_RA	0x40110041
 #define	PVR_405CR_RB	0x401100C5
 #define	PVR_405CR_RC	0x40110145  /* same as pc405gp rev e */
-#define	PVR_405GPR_RA	0x50910951
+#define	PVR_405GPR_RB	0x50910951
 #define	PVR_440GP_RB	0x40120440
 #define	PVR_440GP_RC	0x40120481
 #define	PVR_601		0x00010000
